@@ -5,7 +5,6 @@
 #ifndef __PROFILER_H_
 #define __PROFILER_H_
 #include "likwid-marker.h"
-#include "timing.h"
 #include <stddef.h>
 
 #define PROFILE(tag, call)                                                     \
@@ -26,7 +25,11 @@ typedef enum {
 } regions;
 
 extern double _t[NUMREGIONS][NTIMES];
+extern int _SEQ;
 extern void profilerInit();
 extern void profilerPrint(size_t size);
+extern void profilerOpenFile(int region);
+extern void profilerCloseFile(void);
+extern void profilerPrintLine(size_t N, int iter, int j);
 
 #endif // __PROFILER_H
